"""
A bunch of cool widgets built on d3

Get this source from http://github.com/ralphbean/tw2.d3

d3 itself can be found here:  http://mbostock.github.com/d3/
"""

from widgets import (
    BarChart,
)
