.bar rect {
    fill: steelblue;
}

.bar text.value {
    fill: white;
}

.axis {
    shape-rendering: crispEdges;
}

.axis path {
    fill: none;
}

.x.axis line {
    stroke: #fff;
    stroke-opacity: .8;
}

.y.axis path {
    stroke: black;
}
